@@ -103,6 +103,20 @@ func TestDefaultsConfiguration(t *testing.T) {
 		data: map[string]string{
 			"enable-service-links": "false",
 		},
+	}, {
+		name:    "service links default",
+		wantErr: false,
+		wantDefaults: &Defaults{
+			RevisionTimeoutSeconds:        DefaultRevisionTimeoutSeconds,
+			MaxRevisionTimeoutSeconds:     DefaultMaxRevisionTimeoutSeconds,
+			UserContainerNameTemplate:     DefaultUserContainerName,
+			ContainerConcurrencyMaxLimit:  DefaultMaxRevisionContainerConcurrency,
+			AllowContainerConcurrencyZero: true,
+			EnableServiceLinks:            nil,
+		},
+		data: map[string]string{
+			"enable-service-links": "default",
+		},
 	}, {
 		name:    "invalid allow container concurrency zero flag value",
 		wantErr: true,
@@ -218,7 +232,7 @@ func TestTemplating(t *testing.T) {
 
 			def, err := NewDefaultsConfigFromMap(configMap.Data)
 			if err != nil {
-				t.Errorf("Error parsing defaults: %v", err)
+				t.Error("Error parsing defaults:", err)
 			}
 
 			if diff := cmp.Diff(defCM, def); diff != "" {
